@@ -19,6 +19,7 @@
   def (LINE_UPDATE)
   def (ADD_LINES)
   def (OSC_SEQ)
+  def (OSC_SEQ_PERL)
   def (TT_WRITE)
 
   def (REFRESH_BEGIN)
@@ -26,6 +27,7 @@
 
   def (USER_COMMAND)
 
+  def (ROOT_EVENT)
   def (X_EVENT)
   def (FOCUS_IN)
   def (FOCUS_OUT)
