@@ -1,6 +1,6 @@
 /*
     iom.h -- generic I/O multiplexer
-    Copyright (C) 2003, 2004 Marc Lehmann <gvpe@schmorp.de>
+    Copyright (C) 2003-2006 Marc Lehmann <gvpe@schmorp.de>
  
     This file is part of GVPE.
 
@@ -28,23 +28,12 @@
 // edit iom_conf.h as appropriate.
 #include "iom_conf.h"
 
-#include "callback.h"
+#if IOM_CHILD
+# undef IOM_SIG
+# define IOM_SIG 1
+#endif
 
-#ifndef IOM_IO
-# define IOM_IO 0
-#endif
-#ifndef IOM_TIME
-# define IOM_TIME 0
-#endif
-#ifndef IOM_CHECK
-# define IOM_CHECK 0
-#endif
-#ifndef IOM_IDLE
-# define IOM_IDLE 0
-#endif
-#ifndef IOM_SIG
-# define IOM_SIG 0
-#endif
+#include "callback.h"
 
 typedef double tstamp;
 extern tstamp NOW;
@@ -68,6 +57,9 @@ struct idle_watcher;
 #if IOM_SIG
 struct sig_watcher;
 #endif
+#if IOM_CHILD
+struct child_watcher;
+#endif
 
 template<class watcher>
 struct io_manager_vec : vector<watcher *> {
@@ -115,6 +107,9 @@ public:
 #if IOM_SIG
   static void reg (sig_watcher   &w); static void unreg (sig_watcher   &w);
 #endif
+#if IOM_CHILD
+  static void reg (child_watcher &w); static void unreg (child_watcher &w);
+#endif
   
   static void loop ();
 };
@@ -122,13 +117,15 @@ public:
 struct watcher {
   int active; /* 0 == inactive, else index into respective vector */
 
+  bool is_active () { return active; }
+
   watcher () : active (0) { }
 };
 
 #if IOM_IO
 enum { EVENT_UNDEF = -1, EVENT_NONE = 0, EVENT_READ = 1, EVENT_WRITE = 2 };
 
-struct io_watcher : watcher, callback2<void, io_watcher &, short> {
+struct io_watcher : watcher, callback<void (io_watcher &, short)> {
   int fd;
   short events;
 
@@ -139,16 +136,16 @@ struct io_watcher : watcher, callback2<void, io_watcher &, short> {
   void start (int fd_, short events_) { set (fd_, events_); io_manager::reg (*this); }
   void stop () { io_manager::unreg (*this); }
 
-  template<class O1, class O2>
-  io_watcher (O1 *object, void (O2::*method) (io_watcher &, short))
-  : callback2<void, io_watcher &, short> (object,method)
+  template<class O, class M>
+  io_watcher (O object, M method)
+  : callback<void (io_watcher &, short)> (object, method)
   { }
   ~io_watcher () { stop (); }
 };
 #endif
 
 #if IOM_TIME
-struct time_watcher : watcher, callback1<void, time_watcher &> {
+struct time_watcher : watcher, callback<void (time_watcher &)> {
   tstamp at;
 
   void trigger ();
@@ -159,9 +156,9 @@ struct time_watcher : watcher, callback1<void, time_watcher &> {
   void start (tstamp when) { set (when); io_manager::reg (*this); }
   void stop () { io_manager::unreg (*this); }
 
-  template<class O1, class O2>
-  time_watcher (O1 *object, void (O2::*method) (time_watcher &))
-  : callback1<void, time_watcher &> (object,method), at (0)
+  template<class O, class M>
+  time_watcher (O object, M method)
+  : callback<void (time_watcher &)> (object, method), at (0)
   { }
   ~time_watcher () { stop (); }
 };
@@ -169,13 +166,13 @@ struct time_watcher : watcher, callback1<void, time_watcher &> {
 
 #if IOM_CHECK
 // run before checking for new events
-struct check_watcher : watcher, callback1<void, check_watcher &> {
+struct check_watcher : watcher, callback<void (check_watcher &)> {
   void start () { io_manager::reg (*this); }
   void stop () { io_manager::unreg (*this); }
 
-  template<class O1, class O2>
-  check_watcher (O1 *object, void (O2::*method) (check_watcher &))
-  : callback1<void, check_watcher &> (object,method)
+  template<class O, class M>
+  check_watcher (O object, M method)
+  : callback<void (check_watcher &)> (object, method)
   { }
   ~check_watcher () { stop (); }
 };
@@ -183,32 +180,47 @@ struct check_watcher : watcher, callback1<void, check_watcher &> {
 
 #if IOM_IDLE
 // run after checking for any i/o, but before waiting
-struct idle_watcher : watcher, callback1<void, idle_watcher &> {
+struct idle_watcher : watcher, callback<void (idle_watcher &)> {
   void start () { io_manager::reg (*this); }
   void stop () { io_manager::unreg (*this); }
 
-  template<class O1, class O2>
-  idle_watcher (O1 *object, void (O2::*method) (idle_watcher &))
-    : callback1<void, idle_watcher &> (object,method)
+  template<class O, class M>
+  idle_watcher (O object, M method)
+    : callback<void (idle_watcher &)> (object, method)
     { }
   ~idle_watcher () { stop (); }
 };
 #endif
 
 #if IOM_SIG
-struct sig_watcher : watcher, callback1<void, sig_watcher &> {
+struct sig_watcher : watcher, callback<void (sig_watcher &)> {
   int signum;
 
   void start (int signum);
   void stop () { io_manager::unreg (*this); }
 
-  template<class O1, class O2>
-  sig_watcher (O1 *object, void (O2::*method) (sig_watcher &))
-  : callback1<void, sig_watcher &> (object,method), signum (-1)
+  template<class O, class M>
+  sig_watcher (O object, M method)
+  : callback<void(sig_watcher &)> (object, method), signum (0)
   { }
   ~sig_watcher () { stop (); }
 };
 #endif
 
+#if IOM_CHILD
+struct child_watcher : watcher, callback<void (child_watcher &, int)> {
+  int /*pid_t*/ pid;
+
+  void start (int pid) { this->pid = pid; io_manager::reg (*this); }
+  void stop () { io_manager::unreg (*this); }
+
+  template<class O, class M>
+  child_watcher (O object, M method)
+  : callback<void (child_watcher &, int)> (object, method), pid (0)
+  { }
+  ~child_watcher () { stop (); }
+};
+#endif
+
 #endif
 
